AttemptError

Enum AttemptError 

pub enum AttemptError {
    IllegalTransition {
        from: AttemptState,
        to: AttemptState,
    },
    Workspace(WorkspaceError),
    BusyCannotBeCleaned,
    OutcomeUnreachable {
        from: AttemptState,
        outcome: AttemptOutcome,
    },
    TerminalWithoutOutcome {
        state: AttemptState,
    },
    NonTerminalWithOutcome {
        state: AttemptState,
        outcome: AttemptOutcome,
    },
    OutcomeStateMismatch {
        state: AttemptState,
        outcome: AttemptOutcome,
    },
    TerminalWithoutTimestamp {
        state: AttemptState,
    },
    NonTerminalWithTimestamp {
        state: AttemptState,
    },
    TimestampsOutOfOrder {
        state: AttemptState,
        field: &'static str,
        created_at: Timestamp,
        found: Timestamp,
    },
}

Variants



IllegalTransition



Workspace(WorkspaceError)

A stored workspace kind and slot that cannot describe one allocation, so the legal cleanup algorithm for the journalled path is undecidable.



BusyCannotBeCleaned



OutcomeUnreachable

Fields



TerminalWithoutOutcome

Fields



NonTerminalWithOutcome

Fields



OutcomeStateMismatch

Fields



TerminalWithoutTimestamp

Fields



NonTerminalWithTimestamp

Fields



TimestampsOutOfOrder

Fields

field: &'static str

Which of the two orderable timestamps is out of order.

created_at: Timestamp