PolicyError

Enum PolicyError 

pub enum PolicyError {
    Invalid(ValidationError),
    Workspace(WorkspaceError),
    AutoscaleWithoutRoutingLabels,
    AutoscaleWithoutMaxCapacity,
    MonitorOnlyWithMinCapacity {
        min: u16,
    },
    InvertedCapacityRange {
        min: u16,
        max: u16,
    },
    IllegalTransition {
        from: PolicyState,
        to: PolicyState,
    },
    AlreadyAutoscale,
    NotAutoscale,
    HostLabelNotRemovable {
        label: Label,
    },
}

Variants



Invalid(ValidationError)



Workspace(WorkspaceError)

A workspace configuration this policy’s target cannot hold, or a stored pair of workspace columns this crate cannot have written (D4, D7).



AutoscaleWithoutRoutingLabels



AutoscaleWithoutMaxCapacity



MonitorOnlyWithMinCapacity

Fields

min: u16


InvertedCapacityRange

Fields

min: u16
max: u16


IllegalTransition



AlreadyAutoscale



NotAutoscale



HostLabelNotRemovable

Fields

label: Label