pub enum AttemptError {
IllegalTransition {
from: AttemptState,
to: AttemptState,
},
Workspace(WorkspaceError),
BusyCannotBeCleaned,
OutcomeUnreachable {
from: AttemptState,
outcome: AttemptOutcome,
},
TerminalWithoutOutcome {
state: AttemptState,
},
NonTerminalWithOutcome {
state: AttemptState,
outcome: AttemptOutcome,
},
OutcomeStateMismatch {
state: AttemptState,
outcome: AttemptOutcome,
},
TerminalWithoutTimestamp {
state: AttemptState,
},
NonTerminalWithTimestamp {
state: AttemptState,
},
TimestampsOutOfOrder {
state: AttemptState,
field: &'static str,
created_at: Timestamp,
found: Timestamp,
},
}Variants
IllegalTransition
Workspace(WorkspaceError)
A stored workspace kind and slot that cannot describe one allocation, so the legal cleanup algorithm for the journalled path is undecidable.
BusyCannotBeCleaned
OutcomeUnreachable
TerminalWithoutOutcome
Fields

state: AttemptStateNonTerminalWithOutcome
OutcomeStateMismatch
TerminalWithoutTimestamp
Fields

state: AttemptStateNonTerminalWithTimestamp
Fields

state: AttemptStateTimestampsOutOfOrder